@@ -4,14 +4,24 @@ poses.py
 
 Find stable orientations of meshes.
 """
-import networkx as nx
 import numpy as np
 
 from .triangles import points_to_barycentric
 
+try:
+    import networkx as nx
+except BaseException as E:
+    # create a dummy module which will raise the ImportError
+    # or other exception only when someone tries to use networkx
+    from .exceptions import ExceptionModule
+    nx = ExceptionModule(E)
 
-def compute_stable_poses(mesh, center_mass=None,
-                         sigma=0.0, n_samples=1, threshold=0.0):
+
+def compute_stable_poses(mesh,
+                         center_mass=None,
+                         sigma=0.0,
+                         n_samples=1,
+                         threshold=0.0):
     """
     Computes stable orientations of a mesh and their quasi-static probabilites.
 
@@ -20,10 +30,10 @@ def compute_stable_poses(mesh, center_mass=None,
     equal to and identity matrix times sigma, over n_samples.
 
     For each sample, it computes the stable resting poses of the mesh on a
-    a planar workspace and evaulates the probabilities of landing in
+    a planar workspace and evaluates the probabilities of landing in
     each pose if the object is dropped onto the table randomly.
 
-    This method returns the 4x4 homogenous transform matrices that place
+    This method returns the 4x4 homogeneous transform matrices that place
     the shape against the planar surface with the z-axis pointing upwards
     and a list of the probabilities for each pose.
 
@@ -32,24 +42,30 @@ def compute_stable_poses(mesh, center_mass=None,
 
     Parameters
     ----------
-    mesh:      Trimesh object, the target mesh
-    com:       (3,) float,     the object center of mass (if None, this method
-                               assumes uniform density and watertightness and
-                               computes a center of mass explicitly)
-    sigma:     float,          the covariance for the multivariate gaussian used
-                               to sample center of mass locations
-    n_samples: int,            the number of samples of the center of mass loc
-    threshold: float,          the probability value at which to threshold
-                               returned stable poses
+    mesh : trimesh.Trimesh
+      The target mesh
+    com : (3,) float
+      Rhe object center of mass. If None, this method
+      assumes uniform density and watertightness and
+      computes a center of mass explicitly
+    sigma : float
+      Rhe covariance for the multivariate gaussian used
+      to sample center of mass locations
+    n_samples : int
+      The number of samples of the center of mass location
+    threshold : float
+      The probability value at which to threshold
+      returned stable poses
 
     Returns
     -------
-    transforms: list of (4,4) floats, the homogenous matrices that transform the
-                                     object to rest in a stable pose, with the
-                                     new z-axis pointing upwards from the table
-                                     and the object just touching the table.
-
-    probs:      list of floats,       a probability in (0, 1) for each pose
+    transforms : (n, 4, 4) float
+      The homogeneous matrices that transform the
+      object to rest in a stable pose, with the
+      new z-axis pointing upwards from the table
+      and the object just touching the table.
+    probs : (n,) float
+      Probability in (0, 1) for each pose
     """
 
     # save convex hull mesh to avoid a cache check
@@ -89,17 +105,17 @@ def compute_stable_poses(mesh, center_mass=None,
                 if dg.out_degree(node) == 0:
                     continue
                 successor = next(iter(dg.successors(node)))
-                dg.node[successor]['prob'] += dg.node[node]['prob']
-                dg.node[node]['prob'] = 0.0
+                dg.nodes[successor]['prob'] += dg.nodes[node]['prob']
+                dg.nodes[node]['prob'] = 0.0
                 new_nodes.append(successor)
             nodes = new_nodes
             n_iters += 1
 
         # Collect stable poses
         for node in dg.nodes():
-            if dg.node[node]['prob'] > 0.0:
+            if dg.nodes[node]['prob'] > 0.0:
                 normal = cvh.face_normals[node]
-                prob = dg.node[node]['prob']
+                prob = dg.nodes[node]['prob']
                 key = tuple(np.around(normal, decimals=3))
                 if key in norms_to_probs:
                     norms_to_probs[key]['prob'] += 1.0 / n_samples * prob
@@ -227,13 +243,16 @@ def _create_topple_graph(cvh_mesh, com):
 
     Parameters
     ----------
-    cvh_mesh: Trimesh object, the convex hull of the target shape
-    com:      (3,) float, the 3D location of the target shape's center of mass
+    cvh_mesh : trimesh.Trimesh
+      Rhe convex hull of the target shape
+    com : (3,) float
+      The 3D location of the target shape's center of mass
 
     Returns
     -------
-    graph: networkx.DiGraph(), graph representing static probabilities and toppling
-                               order for the convex hull
+    graph : networkx.DiGraph
+      Graph representing static probabilities and toppling
+      order for the convex hull
     """
     adj_graph = nx.Graph()
     topple_graph = nx.DiGraph()
